@@ -15,8 +15,7 @@ import os
 import re
 import sys
 
-from logan.settings import create_default_settings, load_settings, \
-  add_settings
+from logan.settings import create_default_settings, install_settings
 
 
 def sanitize_name(project):
@@ -121,12 +120,13 @@ def run_app(project=None, default_config_path=None, default_settings=None,
         raise ValueError("Configuration file does not exist. Use '%s init' to initialize the file." % runner_name)
 
     if default_settings:
-        settings_mod = import_module(default_settings)
+        default_settings_mod = import_module(default_settings)
         # TODO: logan should create a proxy module for its settings
-        management.setup_environ(settings_mod, default_settings)
-        add_settings(settings_mod, allow_extras=allow_extras)
+        # management.setup_environ(settings_mod, default_settings)
+    else:
+        default_settings_mod = None
 
-    load_settings(config_path, allow_extras=allow_extras)
+    install_settings(config_path, default_settings_mod, allow_extras=allow_extras)
 
     if initializer is not None:
         from django.conf import settings
